<?php
/**
 * Pixeldom Lite functions and definitions
 *
 * @link https://www.themebounce.com/themes/pixeldom/
 *
 * @package WordPress
 * @subpackage Pixeldom Lite
 * @since 1.0
 */


/*  Google Fonts  */

	$pixeldom_lite_theme_path = get_template_directory() . '/inc/';

	require( $pixeldom_lite_theme_path . '/font/font.php');

function pixeldom_lite_setup(){
	
	/*
	 * Make theme available for translation.
	 */
	load_theme_textdomain( 'pixeldom-lite' );
	
	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( "title-tag" );

	/* 
	 * Custom Background
	 */
	add_theme_support( "custom-background" );

	/* 
	 * Custom Header
	 */
	add_theme_support( "custom-header" );	

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support('post-thumbnails');
	add_image_size('full-thumb', 940, 0, true);
	add_image_size('slider-thumb', 650, 440, true);
	add_image_size('thumb', 440, 294, true);
	
	// Set the default content width.
	$GLOBALS['content_width'] = 940;

	// Theme wp_nav_menu().
	register_nav_menus( array(
		'main-menu' => __('Primary Menu', 'pixeldom-lite' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

}

add_action('after_setup_theme', 'pixeldom_lite_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'id'   => 'sidebar',
		'name' => __( 'Sidebar', 'pixeldom-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
}
if (function_exists('register_sidebar')) {
	function pixeldom_lite_widgets_init(){}	
add_action('widgets_init', 'pixeldom_lite_widgets_init');
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since Pixeldom Lite 1.0
 *
 * @param string $link Link to single post/page.
 * @return &hellip.
 */
function pixeldom_lite_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'pixeldom-lite' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' ;
}
add_filter( 'excerpt_more', 'pixeldom_lite_excerpt_more' );

/**
 * Enqueue scripts and styles.
 */

function pixeldom_lite_load_scripts()
{	
	//Theme stylesheet.
	wp_enqueue_style('pixeldom-lite-style', get_stylesheet_directory_uri() . '/style.css');

	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css');
	
	wp_enqueue_script('pixeldom-lite-scripts', get_template_directory_uri() . '/assets/js/pixeldom.js', 'jquery', '', true);
	wp_enqueue_script('jquery');

	if (is_singular() && get_option('thread_comments')) wp_enqueue_script('comment-reply');
}
	add_action('wp_enqueue_scripts', 'pixeldom_lite_load_scripts');


/**
 * PAGINATION.
 */
function pixeldom_lite_pagination() {
	
	?>
	
	<div class="pagination">

		<div class="older"><?php next_posts_link(__( 'Older Posts <i class="fa fa-angle-double-right"></i>', 'pixeldom-lite')); ?></div>
		<div class="newer"><?php previous_posts_link(__( '<i class="fa fa-angle-double-left"></i> Newer Posts', 'pixeldom-lite')); ?></div>
		
	</div>
					
	<?php
	
}

/**
 * COMMENTS LAYOUT.
 */
function pixeldom_lite_comments($comment, $args, $depth) {
		$comment = $GLOBALS['comment'];
		
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
			
			<div class="thecomment">
						
				<div class="author-img">
					<?php echo get_avatar($comment,$args['avatar_size']); ?>
				</div>
				
				<div class="comment-text">
					<span class="reply">
						<?php comment_reply_link(array_merge( $args, array('reply_text' => __('Reply', 'pixeldom-lite'), 'depth' => $depth, 'max_depth' => $args['max_depth'])), $comment->comment_ID); ?>
						<?php edit_comment_link(__('Edit', 'pixeldom-lite')); ?>
					</span>
					<span class="author"><?php echo get_comment_author_link(); ?></span>
					<span class="date"><?php printf(esc_html__('%1$s at %2$s', 'pixeldom-lite'), get_comment_date(),  get_comment_time()) ?></span>
					<?php if ($comment->comment_approved == '0') : ?>
						<em><i class="icon-info-sign"></i> <?php esc_html_e('Comment awaiting approval', 'pixeldom-lite'); ?></em>
						<br />
					<?php endif; ?>
					<?php comment_text(); ?>
				</div>
						
			</div>
			
			
		</li>

		<?php 
}

/**
 * EXCLUDE FEATURED CATEGORY.
 */
function pixeldom_lite_category($separator) {
		
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($first_time == 1) {
				echo '<a href="' . esc_html(get_category_link( $category->term_id )) . '" title="' . sprintf( esc_html__( "View all posts in %s", "pixeldom-lite" ), esc_html($category->name) ) . '" ' . '>'  . esc_html($category->name).'</a>';
				$first_time = 0;
			} else {
				echo esc_html($separator) . '<a href="' . esc_html(get_category_link( $category->term_id )) . '" title="' . sprintf( esc_html__( "View all posts in %s", "pixeldom-lite" ), esc_html($category->name) ) . '" ' . '>' . esc_html($category->name).'</a>';
			}
		}
}